@@ -22,7 +22,7 @@
 #include "declarations_definitions_and_enumerations.h"
 #include "context_menu.h"
 
-// CM = context menu, indicating that the enums are only used here
+// CM = context menu; indicates that these enums are only used in this file.
 enum { CM_RECURSIVELY, CM_IMMEDIATE, CM_COLLAPSE, CM_NUMBER_OF_EXPANSION_STATUS_CHANGES };
 
 typedef struct {
@@ -42,7 +42,7 @@ static void expand_or_collapse_selected_rows (const gpointer action_pointer);
 
 /* 
 
-    Creates a headline inside the context menu.
+    Creates a headline (label) inside the context menu.
 
 */
 
@@ -67,7 +67,7 @@ static void create_cm_headline (      GtkWidget *context_menu,
 
 /* 
 
-    Expands or collapses all selected rows according to the choice done.
+    Expands or collapses all selected rows based on the chosen action.
 
 */
 
@@ -87,8 +87,8 @@ static void expand_or_collapse_selected_rows (const gpointer action_pointer)
     FOREACH_IN_LIST (selected_rows, selected_rows_loop) {
         GtkTreePath *path_loop = selected_rows_loop->data;
         /*
-            If the nodes are already expanded recursively and only the immediate children shall be expanded now, 
-            it is the fastest way to collapse all nodes first.
+            If the nodes are already expanded recursively and only immediate children should be expanded now, 
+            the fastest approach is to collapse all nodes first.
         */
         gtk_tree_view_collapse_row (GTK_TREE_VIEW (ks.treeview), path_loop);
         if (action == CM_COLLAPSE) {
@@ -107,7 +107,7 @@ static void expand_or_collapse_selected_rows (const gpointer action_pointer)
 
 /* 
 
-    Adds all currently unused startupnotify or Execute options to the context menu.
+    Adds all currently unused Startupnotify or Execute options to the context menu.
 
 */
 
@@ -117,17 +117,17 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
                                                                   const guint8        number_of_opts, 
                                                                   const gchar       **options_array)
 {
-    const gchar *menu_item_txts_exe_opts[] = { // Translation note: Do not translate "Prompt". This is for a context menu.
+    const gchar *menu_item_txts_exe_opts[] = { // Translation note: Do not translate the word "Prompt". Context menu label.
 	                                           N_("Add Prompt"), 
-	                                           // Translation note: Do not translate "Command". This is for a context menu.
+	                                           // Translation note: Do not translate the word "Command". Context menu label.
 	                                           N_("Add Command"),
-											   // Translation note: Do not translate "Startupnotify". This is for a context menu.
+											   // Translation note: Do not translate the word "Startupnotify". Context menu label.
 											   N_("Add Startupnotify") };
-    const gchar *menu_item_txts_snotify_opts[] = { // Translation note: Do not translate "Enabled". This is for a context menu.
+    const gchar *menu_item_txts_snotify_opts[] = { // Translation note: Do not translate the word "Enabled". Context menu label.
 	                                               N_("Add Enabled"), 
-	                                               // Translation note: Do not translate "Name". This is for a context menu.
+	                                               // Translation note: Do not translate the word "Name". Context menu label.
 	                                               N_("Add Name"),
-												   // Translation note: Do not translate "WM_CLASS". This is for a context menu.
+												   // Translation note: Do not translate the word "WM_CLASS". Context menu label.
 												   N_("Add WM_CLASS") }; // Without Icon, because of context used below.
     g_autofree gboolean *opts_exist = g_malloc0 (sizeof (gboolean) * number_of_opts); // Initialize all elements to FALSE.
     GtkWidget *menu_item;
@@ -137,7 +137,7 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
 
     for (guint8 opts_cnt = 0; opts_cnt < number_of_opts; ++opts_cnt) {    
         if (!opts_exist[opts_cnt]) {
-			// Translation note: Do not translate "Icon". This is for a context menu.
+			// Translation note: Do not translate the word "Icon". Context menu label.
             menu_item = gtk_menu_item_new_with_label ((startupnotify_opts) ? ((opts_cnt < number_of_opts - 1) ? _(menu_item_txts_snotify_opts[opts_cnt]) : C_("Context Menu|Child of Startupnotify", "Add Icon")) : 
                                                       _(menu_item_txts_exe_opts[opts_cnt]));
 
@@ -152,7 +152,7 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
 
 /* 
 
-    Right click on the treeview presents a context menu for adding, changing, and deleting menu elements.
+    Displays a context menu (on right-click) for adding, modifying, and removing menu elements.
 
 */
 
@@ -162,8 +162,8 @@ void create_context_menu (GdkEventButton *event)
     GtkWidget *menu_item;
 
     GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ks.treeview));
-    /* Not const; if two or more rows had been selected before and another row not one of these has now been rightclicked, 
-       number_of_selected_rows has to be reset. */
+    /* Not const; if two or more rows were selected before and another row (not among them) is right-clicked,
+       number_of_selected_rows must be updated. */
     gint number_of_selected_rows = gtk_tree_selection_count_selected_rows (selection);
 #if GLIB_CHECK_VERSION(2,56,0)
     g_autolist(GtkTreePath) selected_rows = NULL;
@@ -175,10 +175,10 @@ void create_context_menu (GdkEventButton *event)
     GList *selected_rows_loop;
     GtkTreeIter iter_loop;
 
-    // The last three arguments (column, cell_x and cell_y) aren't used.
+    // The last three arguments (column, cell_x, and cell_y) are unused.
     gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (ks.treeview), event->x, event->y, &path, NULL, NULL, NULL);
 
-    // Don't show a context menu when the new menu element screen is open and there is a right click outside the tree view.
+    // Do not show a context menu if the “new menu element” screen is open and the right-click is outside the tree.
     if (!path && gtk_widget_get_visible (ks.enter_values_box)) {
         return;
     }
@@ -186,12 +186,12 @@ void create_context_menu (GdkEventButton *event)
     context_menu = gtk_menu_new ();
 
     if (path) {
-        gboolean selected_row_is_one_of_the_previously_selected_ones = FALSE; // Default
+        gboolean selected_row_is_one_of_the_previously_selected_ones = FALSE; // Default value.
 
         if (number_of_selected_rows > 1) {
             /*
-                If several rows are selected and a row that is not one of these is rightclicked, 
-                select the latter and unselect the former ones.
+                If multiple rows are selected and a different row (not among them) is right-clicked,
+                select that row and unselect the others.
             */
             selected_rows = gtk_tree_selection_get_selected_rows (selection, &ks.ts_model);
             FOREACH_IN_LIST (selected_rows, selected_rows_loop) {
@@ -204,9 +204,9 @@ void create_context_menu (GdkEventButton *event)
                 g_list_free_full (selected_rows, (GDestroyNotify) gtk_tree_path_free);
             }
             else {
-                gboolean at_least_one_row_has_no_icon = FALSE; // Default
+                gboolean at_least_one_row_has_no_icon = FALSE; // Default value.
 
-                // Add context menu item for deletion of icons if all selected rows contain icons.
+                // Add menu item to remove icons if all selected rows have icons.
                 FOREACH_IN_LIST (selected_rows, selected_rows_loop) {
                     g_autoptr(GdkPixbuf) icon_img_pixbuf_loop;
                 
@@ -228,32 +228,38 @@ void create_context_menu (GdkEventButton *event)
         }
 
         /*
-            Either no or one row had been selected before or 
-            two or more rows had been selected before and another row not one of these has now been rightclicked.
+            Either fewer than two rows were previously selected, 
+            or multiple rows were selected but a different row was right-clicked.
         */
         if (number_of_selected_rows < 2 || !selected_row_is_one_of_the_previously_selected_ones) {
-            gboolean not_all_options_of_selected_action_set = FALSE; // Default
+            gboolean not_all_options_of_selected_action_set = FALSE; // Default value.
 
             gtk_tree_selection_unselect_all (selection);
             gtk_tree_selection_select_path (selection, path);
             selected_rows = gtk_tree_selection_get_selected_rows (selection, &ks.ts_model);
-            number_of_selected_rows = 1; // If there had not been a selection before.
+            number_of_selected_rows = 1; // In case there was no prior selection.
 
             // Icon
             if (streq_any (ks.txt_fields[TYPE_TXT], "menu", "pipe menu", "item", NULL)) {
                 if (STREQ (ks.txt_fields[TYPE_TXT], "item")) {
-                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
-                    create_cm_headline (context_menu, _(" Icon")); // Items have "Icon" and "Action" as context menu headlines.
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                    // please use the indefinite form (“Icon”), not the definite one (“The Icon”).
+                    create_cm_headline (context_menu, _(" Icon")); // Items use "Icon" and "Action" as context menu headlines.
                 }
 
-                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon), not the definite one (“The Icon”).
+                menu_item = gtk_menu_item_new_with_label ((ks.txt_fields[ICON_PATH_TXT]) ? // Translation note: Context menu label. 
+                                                                                           // If the target language distinguishes between definite and indefinite forms, 
+                                                                                           // please use the indefinite form (“Icon), not the definite one (“The Icon”).
                                                                                            _("Change Icon") : 
-                                                                                           // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
+                                                                                           // Translation note: Context menu label.
+                                                                                           // If the target language distinguishes between definite and indefinite forms, 
+                                                                                           // please use the indefinite form (“Icon”), not the definite one (“The Icon”).
                                                                                            C_("Context Menu|Menu or Item", "Add Icon"));
                 g_signal_connect (menu_item, "activate", G_CALLBACK (icon_choosing_by_button_or_context_menu), NULL);
                 gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
                 if (ks.txt_fields[ICON_PATH_TXT]) {
-                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Icon”), not the definite one (“The Icon”).
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                    // please use the indefinite form (“Icon”), not the definite one (“The Icon”).
                     menu_item = gtk_menu_item_new_with_label (_("Remove Icon"));
                     g_signal_connect (menu_item, "activate", G_CALLBACK (remove_icons_from_menus_or_items), GUINT_TO_POINTER (TRUE));
                     gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
@@ -281,9 +287,9 @@ void create_context_menu (GdkEventButton *event)
                         const gint number_of_chldn_of_gp = gtk_tree_model_iter_n_children (ks.ts_model, &grandparent);
 
                         if (STREQ (ks.txt_fields[TYPE_TXT], "option block") && number_of_chldn_of_gp < NUMBER_OF_EXECUTE_OPTS) {
-							// Translation note: Do not translate "Startupnotify"
+							// Translation note: Do not translate the word "Startupnotify".
                             gchar *headline_txt = (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_STARTUPNOTIFY_OPTS - 1) ? _(" Startupnotify Option") : 
-                                                                                                                                                // Translation note: Do not translate "Startupnotify"
+                                                                                                                                                // Translation note: Do not translate the word "Startupnotify".
                                                                                                                                                 // 2-4 options are possible.
                                                                                                                                                 _(" Startupnotify Options"); 
 
@@ -294,7 +300,7 @@ void create_context_menu (GdkEventButton *event)
                                                                               NUMBER_OF_STARTUPNOTIFY_OPTS,
                                                                               ks.startupnotify_options);
 
-                        // No "Execute option(s)" headline following.
+                        // No "Execute option(s)" headline follows here.
                         if (number_of_chldn_of_gp == NUMBER_OF_EXECUTE_OPTS || STREQ (ks.txt_fields[TYPE_TXT], "option")) {
                             gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), gtk_separator_menu_item_new ());
                         }
@@ -320,9 +326,9 @@ void create_context_menu (GdkEventButton *event)
                         if (STREQ (ks.txt_fields[TYPE_TXT], "action") || 
                             (STREQ (ks.txt_fields[TYPE_TXT], "option block") && 
                             gtk_tree_model_iter_n_children (ks.ts_model, &ks.iter) < NUMBER_OF_STARTUPNOTIFY_OPTS)) {
-							// Translation note: Do not translate "Execute"
+							// Translation note: Do not translate the word "Execute".
                             gchar *headline_txt = (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_EXECUTE_OPTS - 1) ? _(" Execute Option") : 
-                                                                                                                                          // Translation note: Do not translate "Execute"
+                                                                                                                                          // Translation note: Do not translate the word "Execute".
                                                                                                                                           // 2-5 options are possible.
                                                                                                                                           _(" Execute Options");
 
@@ -335,29 +341,29 @@ void create_context_menu (GdkEventButton *event)
                         if (STREQ (ks.txt_fields[TYPE_TXT], "action")) {
                             not_all_options_of_selected_action_set = TRUE;
                         }
-                        else { // If "Execute" is selected, the headline for the actions follows.
+                        else { // If "Execute" is selected, the headline for the actions section follows.
                             gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), gtk_separator_menu_item_new ());
                         }
                     }
                 }
 
-                // Option of "Exit"/"SessionLogout" (prompt) or "Restart" action (command)
+                // Options for "Exit" / "SessionLogout" (prompt) or "Restart" action (command)
                 if (STREQ (ks.txt_fields[TYPE_TXT], "action") && 
                     streq_any (ks.txt_fields[MENU_ELEMENT_TXT], "Exit", "SessionLogout", "Restart", NULL) && 
                     !gtk_tree_model_iter_has_child (ks.ts_model, &ks.iter)) {
                     const gboolean restart = STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Restart");
-					// Translation note: Do not translate "Restart"
+					// Translation note: Do not translate the word "Restart".
                     create_cm_headline (context_menu, (restart) ? _(" Restart Option") : 
                                         (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Exit") ? 
-										// Translation note: Do not translate "Exit"
+										// Translation note: Do not translate the word "Exit".
                                         _(" Exit Option") : 
-										// Translation note: Do not translate "SessionLogout"
+										// Translation note: Do not translate the word "SessionLogout".
 										_(" SessionLogout Option")));
 										                                  
                     menu_item = gtk_menu_item_new_with_label ((restart) ? 
-					                                         // Translation note: Do not translate "Command". This is for a context menu.
+					                                         // Translation note: Do not translate the word "Command". Context menu label.
 					                                         _("Add Command") : 
-					                                         // Translation note: Do not translate "Prompt". This is for a context menu.
+					                                         // Translation note: Do not translate the word "Prompt". Context menu label.
 					                                         _("Add Prompt"));
                     g_signal_connect_swapped (menu_item, "activate", G_CALLBACK (add_new), (restart) ? "command" : "prompt");
                     gtk_menu_shell_append (GTK_MENU_SHELL (context_menu), menu_item);
@@ -369,20 +375,21 @@ void create_context_menu (GdkEventButton *event)
             // Actions
             if (streq_any (ks.txt_fields[TYPE_TXT], "item", "action", NULL)) {
                 if (STREQ (ks.txt_fields[TYPE_TXT], "item") || not_all_options_of_selected_action_set) {
-                    // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Actions”), not the definite one (“The Actions”).
+                    // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                    // please use the indefinite form (“Actions”), not the definite one (“The Actions”).
                     create_cm_headline (context_menu, _(" Actions"));
                 }
 
                 for (guint8 actions_cnt = 0; actions_cnt < NUMBER_OF_ACTIONS; ++actions_cnt) {
-                    const gchar *menu_item_txts[] = { // Translation note: Do not translate "Execute". This is for a context menu.
+                    const gchar *menu_item_txts[] = { // Translation note: Do not translate the word "Execute". Context menu label.
 					                                  N_("Add Execute"), 
-					                                  // Translation note: Do not translate "Exit". This is for a context menu.
+					                                  // Translation note: Do not translate the word "Exit". Context menu label.
 					                                  N_("Add Exit"), 
-													  // Translation note: Do not translate "Reconfigure". This is for a context menu.
+													  // Translation note: Do not translate the word "Reconfigure". Context menu label.
 													  N_("Add Reconfigure"), 
-													  // Translation note: Do not translate "Restart". This is for a context menu.
+													  // Translation note: Do not translate the word "Restart". Context menu label.
 													  N_("Add Restart"), 
-													  // Translation note: Do not translate "SessionLogout". This is for a context menu.
+													  // Translation note: Do not translate the word "SessionLogout". Context menu label.
 													  N_("Add SessionLogout") };
 
                     menu_item = gtk_menu_item_new_with_label (_(menu_item_txts[actions_cnt]));
@@ -400,29 +407,37 @@ void create_context_menu (GdkEventButton *event)
         }
     }
 
-    // Basic menu elements
+    // Basic menu elements section
 
     /*
-        menu, pipe menu, item & separator -> if (txt_fields[ELEMENT_VISIBILITY_TXT]) == TRUE
-        If number of rows is > 1, then txt_fields[ELEMENT_VISIBILITY_TXT] == NULL.
+        menu, pipe menu, item, and separator → only if (txt_fields[ELEMENT_VISIBILITY_TXT]) == TRUE
+        If multiple rows are selected, txt_fields[ELEMENT_VISIBILITY_TXT] will be NULL.
     */
     if (!path || ks.txt_fields[ELEMENT_VISIBILITY_TXT]) {
         const gchar *basic_menu_elements[] = { "menu", "pipe menu", "item", "separator" };
-        const gchar *add_basic_menu_elements_for_cm[] = { // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu”), not the definite one (“The Menu”).
+        const gchar *add_basic_menu_elements_for_cm[] = { // Translation note: Context menu label. If the target language distinguishes between definite and indefinite forms, 
+                                                          // please use the indefinite form (“Menu”), not the definite one (“The Menu”).
 		                                                  N_("Add Menu"), 
-														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
+														  // Translation note: Context menu label. If the target language distinguishes between definite and indefinite forms, 
+														  // please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
 														  N_("Add Pipe Menu"), 
-														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Item”), not the definite one (“The Item”).
+														  // Translation note: Context menu label. If the target language distinguishes between definite and indefinite forms, 
+														  // please use the indefinite form (“Item”), not the definite one (“The Item”).
 														  N_("Add Item"), 
-														  // Translation note: This is for a context menu. If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Separator”), not the definite one (“The Separator”).
+														  // Translation note: Context menu label. If the target language distinguishes between definite and indefinite forms, 
+														  // please use the indefinite form (“Separator”), not the definite one (“The Separator”).
 														  N_("Add Separator") };
-        const gchar *basic_menu_elements_for_cm[] = { // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Menu”), not the definite one (“The Menu”).
+        const gchar *basic_menu_elements_for_cm[] = { // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                                      // please use the indefinite form (“Menu”), not the definite one (“The Menu”).
                                                       N_("Menu"), 
-                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                                      // please use the indefinite form (“Pipe Menu”), not the definite one (“The Pipe Menu”).
                                                       N_("Pipe Menu"), 
-                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Item”), not the definite one (“The Item”).
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                                      // please use the indefinite form (“Item”), not the definite one (“The Item”).
                                                       N_("Item"), 
-                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, please use the indefinite form (“Separator”), not the definite one (“The Separator”).
+                                                      // Translation note: If the target language distinguishes between definite and indefinite forms, 
+                                                      // please use the indefinite form (“Separator”), not the definite one (“The Separator”).
                                                       N_("Separator") };
         const gchar *items[] = { "item+Execute", "item+Exit", "item+Reconfigure", "item+Restart", "item+SessionLogout" };
         enum { MENU, PIPE_MENU, ITEM, SEPARATOR };
@@ -433,7 +448,7 @@ void create_context_menu (GdkEventButton *event)
 
         if (!path) {
             gtk_tree_selection_unselect_all (selection);
-            // Translation note: "Top Level" refers to the top level of a tree view in a GUI. This is for a context menu.
+            // Translation note: "Top Level" refers to the top level of a tree view in a GUI. Context menu label.
             create_cm_headline (context_menu, _(" Add at Top Level"));
         }
 
@@ -475,10 +490,10 @@ void create_context_menu (GdkEventButton *event)
     }
 
     if (path) {
-        // Defaults
+        // Default values.
         b_NodeStatuses      node_statuses                  = { FALSE };
         b_ExpansionStatuses expansion_statuses_of_subnodes = { FALSE };
-        // The address of this variable is sent to a funtion, so it can't be part of a bit field.
+        // This variable’s address is passed to a function, so it cannot be part of a bit field.
         gboolean at_least_one_descendant_is_invisible = FALSE;
 
         GtkTreePath *path_loop;
@@ -526,9 +541,9 @@ void create_context_menu (GdkEventButton *event)
                     g_autofree gchar *menu_item_txt = g_strdup_printf (
                                                                        (exp_status_changes_cnt == CM_RECURSIVELY) ? ( (number_of_selected_rows == 1) ? _("Expand Row Recursively") : _("Expand Rows Recursively") ) : 
                                                                        (
-                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only"
+                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only".
                                                                         (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? _("Expand Row (Imd. Ch. Only)") : 
-                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only"
+                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only".
                                                                                                                                                       _("Expand Rows (Imd. Ch. Only)") ) : 
                                                                                                                     (number_of_selected_rows == 1) ? _("Collapse Row") : _("Collapse Rows")
                                                                        )
@@ -587,15 +602,15 @@ void create_context_menu (GdkEventButton *event)
     gtk_menu_popup_at_pointer (GTK_MENU (context_menu), NULL);
 #else
     /*
-        Arguments two to five 
-        (parent_menu_shell, parent_menu_item, user defined positioning function and user data for that function)
+        Arguments 2 to 5 
+        (parent_menu_shell, parent_menu_item, custom positioning function, and user data for that function)
         are not used.
     */
     gtk_menu_popup (GTK_MENU (context_menu), NULL, NULL, NULL, NULL, event->button, gdk_event_get_time ((GdkEvent*) event));
 #endif
 
 #if !(GLIB_CHECK_VERSION(2,56,0))
-    // Cleanup
+    // Free list of selected rows.
     g_list_free_full (selected_rows, (GDestroyNotify) gtk_tree_path_free);
 #endif
 }
