@@ -152,7 +152,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         if (ks.settings.autosort_options && streq_any (type_txt_loop, "option", "option block", NULL) && 
             streq_any (menu_element_dest_parent_txt, "Execute", "startupnotify", NULL) &&
             gtk_tree_path_compare (source_parent_path, dest_parent_path) == 0) {
-            statusbar_txt = _("!!! Autosorting active - no movement of options inside the same action possible !!!");
+            statusbar_txt = _("!!! Autosorting active – options cannot be moved within the same action !!!");
 
             break;
         }
