@@ -19,12 +19,12 @@
 
 #include <gtk/gtk.h>
 
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "editing.h"
 
-// ED = editing, indicating that the enums are only used here
+// ED = editing; indicates that these enums are only used in this file.
 enum { ED_FILTER_SELECTED_PATH, ED_VISUALISE_RECURSIVELY, ED_NUMBER_OF_FILTER_VISUALISATION_ELEMENTS };
 
 static gboolean add_all_strs_of_tree_column_to_liststore (              GtkTreeModel *foreach_model, 
@@ -43,7 +43,7 @@ static void sort_execute_or_startupnotify_options (      GtkTreeIter *parent,
 
 /* 
 
-    First initiates the sorting of Execute or startupnotify options, then selects the inserted option.
+    First sorts the Execute or Startupnotify options, then selects the newly inserted option.
 
 */
 
@@ -71,9 +71,9 @@ void sort_execute_or_startupnotify_options_after_insertion (      GtkTreeSelecti
 
 /* 
 
-    Sorts Execute or startupnotify options according to the order
-    Execute: 1. prompt, 2. command, 3. startupnotify.
-    startupnotify: 1. enabled, 2. name, 3. wmclass, 4. icon.
+    Sorts Execute or Startupnotify options in the following order:
+    Execute:       1. prompt, 2. command, 3. startupnotify
+    Startupnotify: 1. enabled, 2. name, 3. wmclass, 4. icon
 
 */
 
@@ -86,7 +86,7 @@ static void sort_execute_or_startupnotify_options (      GtkTreeIter *parent,
     for (gint ch_cnt = 0; ch_cnt < gtk_tree_model_iter_n_children (ks.ts_model, parent) - 1; ++ch_cnt) {
         GtkTreeIter iter_loop_ch;
         g_autofree gchar *menu_element_txt_loop_ch;
-        gboolean swapped = FALSE; // Default
+        gboolean swapped = FALSE; // Default value.
 
         gtk_tree_model_iter_nth_child (ks.ts_model, &iter_loop_ch, parent, ch_cnt);
         gtk_tree_model_get (ks.ts_model, &iter_loop_ch, TS_MENU_ELEMENT, &menu_element_txt_loop_ch, -1);
@@ -119,8 +119,8 @@ static void sort_execute_or_startupnotify_options (      GtkTreeIter *parent,
 
 /* 
 
-    This function is run after autosorting of options has been activated.
-    All Execute and startupnotify options of the treestore are sorted by it.
+    Called after autosorting of options is enabled.
+    Sorts all Execute and Startupnotify options in the tree store.
 
 */
 
@@ -151,7 +151,7 @@ gboolean sort_loop_after_sorting_activation (              GtkTreeModel *foreach
 
 /* 
 
-    Moves selection up or down, to the top or bottom.
+    Moves the current selection up, down, to the top, or to the bottom.
 
 */
 
@@ -186,8 +186,8 @@ void move_selection (gpointer direction_pointer)
 
 /* 
 
-    Sets element visibility of menus, pipe menus, items, and separators 
-    that are dependent on the menu element that has been visualized.
+    Sets the element visibility of menus, pipe menus, items, and separators 
+    that depend on the menu element being visualized.
 
 */
 
@@ -210,12 +210,12 @@ static gboolean check_and_adjust_dependent_element_visibilities (GtkTreeModel *f
                      *type_txt_filter;
 
     /*
-        Makes the following conditional statement more readable.
-        If the selected path is on toplevel, filter_visualization[ED_FILTER_SELECTED_PATH] == NULL.
+        This makes the following condition easier to read.
+        If the selected path is at the top level, filter_visualization[ED_FILTER_SELECTED_PATH] == NULL.
     */
     GtkTreePath *filter_selected_path = (GtkTreePath *) filter_visualization[ED_FILTER_SELECTED_PATH];
     const gboolean recursively_and_row_is_dsct = (GPOINTER_TO_UINT (filter_visualization[ED_VISUALISE_RECURSIVELY]) && 
-                                                  (!filter_selected_path || // Selected path is on toplevel = dsct. of NULL.
+                                                  (!filter_selected_path || // Selected path is at the top level = dsct. of NULL.
                                                    gtk_tree_path_is_descendant (filter_path, filter_selected_path)));
 
     gtk_tree_model_get (filter_model, filter_iter, 
@@ -225,16 +225,16 @@ static gboolean check_and_adjust_dependent_element_visibilities (GtkTreeModel *f
     gtk_tree_model_filter_convert_iter_to_child_iter ((GtkTreeModelFilter *) filter_model, &model_iter, filter_iter);
 
     /*
-        Current row is an ancestor of the selected row or the selected row itself.
+	    The current row is an ancestor of, or equal to, the selected row.
 
-        A menu element can only be visible if its ancestors are visible as well, 
-        so if a visualization is done for a (pipe) menu, item or separator, the visibility statuses for all ancestors are 
-        set to "visible". 
-        To keep the code simple there is no check if the visibility status is already set to "visible", it is done anyway. 
-        Visualized menus and items get a "dummy" label, whilst separators don't, because they are always visible if they
-        are not descendants of an invisible menu, whether they have a label or not.
+        A menu element can only be visible if all its ancestors are visible. 
+        When visualizing a (pipe) menu, item, or separator, all ancestors’ visibility statuses 
+        are set to "visible". 
+        For simplicity, this is done without first checking the current status. 
+        Visualized menus and items are given a placeholder label; separators are not, 
+        as they are always visible if not under an invisible menu.
     */
-    if (filter_selected_path && // Selected path is not on toplevel.
+    if (filter_selected_path && // Selected path is not at the top level.
         (gtk_tree_path_is_ancestor (filter_path, filter_selected_path) || 
         gtk_tree_path_compare (filter_path, filter_selected_path) == 0)) {
         gtk_tree_store_set (ks.treestore, &model_iter, TS_ELEMENT_VISIBILITY, "visible", -1);
@@ -242,7 +242,7 @@ static gboolean check_and_adjust_dependent_element_visibilities (GtkTreeModel *f
             gtk_tree_store_set (ks.treestore, &model_iter, TS_MENU_ELEMENT, _("(Newly Created Label)"),  -1);
         }
     }
-    // Current row is a descendant of the selected row or not an ascendant of the selected row/the selected row itself.
+	// Current row is a descendant of the selected row, or unrelated to it.
     else {
         const guint8 invisible_ancestor = check_if_invisible_ancestor_exists (filter_model, filter_path);
         const gboolean unlabeled_menu_or_item = !menu_element_txt_filter && !STREQ (type_txt_filter, "separator");
@@ -264,7 +264,7 @@ static gboolean check_and_adjust_dependent_element_visibilities (GtkTreeModel *f
 
 /* 
 
-    Changes the status of one or more menus, pipe menus, items, and separators to visible.
+    Makes one or more menus, pipe menus, items, or separators visible.
 
 */
 
@@ -349,7 +349,7 @@ void visualize_menus_items_and_separators (gpointer recursively_pointer)
 
 /* 
 
-    File filter is limited to display only image files.
+    File filter that allows only image files to be displayed.
 
 */
 
@@ -361,30 +361,30 @@ static gboolean image_type_filter (              const GtkFileFilterInfo *filter
 
 /* 
 
-    Dialog for choosing an icon for a (pipe) menu or item.
+    Opens a dialog for selecting an icon for a (pipe) menu or item.
 
-    The returned filename is a newly allocated string that should be freed with g_free () after use.
+    Returns a newly allocated filename string that must be freed with g_free() after use.
 
 */
 
 gchar *choose_icon (void)
 {
-	// Translation note: the verb "Open"
+	// Translation note: the verb "Open".
     GtkWidget *dialog = gtk_file_chooser_dialog_new (_("Open Image File"),
                                                      GTK_WINDOW (ks.window), 
                                                      GTK_FILE_CHOOSER_ACTION_OPEN,
                                                      C_("Cancel|File Dialogue", "_Cancel"), GTK_RESPONSE_CANCEL, 
-													 // Translation note: the verb "Open"
+													 // Translation note: the verb "Open".
                                                      _("_Open"), GTK_RESPONSE_ACCEPT, 
                                                      NULL);
 
     GtkFileFilter *open_image_file_filter = gtk_file_filter_new ();
-    gchar *icon_filename = NULL; // Default
+    gchar *icon_filename = NULL; // Default value.
 
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), "/");
 
     gtk_file_filter_set_name (open_image_file_filter, _("Image Files"));
-    // The last two arguments (data and function to call to free data) aren't used.
+    // The last two parameters (data and destroy function) are unused.
     gtk_file_filter_add_custom (open_image_file_filter, GTK_FILE_FILTER_MIME_TYPE, (GtkFileFilterFunc) image_type_filter, 
                                 NULL, NULL);
     gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), open_image_file_filter);
@@ -400,8 +400,8 @@ gchar *choose_icon (void)
 
 /* 
 
-    Lets the user choose an icon after (s)he clicked on the icon chooser button or
-    (s)he chose the corresponding action from the context menu.
+    Lets the user choose an icon after clicking the icon chooser button 
+    or selecting the corresponding action from the context menu.
 
 */
 
@@ -412,9 +412,10 @@ void icon_choosing_by_button_or_context_menu (void)
     if (!(icon_path = choose_icon ())) {
         return;
     }
-    // TRUE = Display error message when error occurs, FALSE = Not during undo/redo
+	// TRUE = show an error message on failure, FALSE = not during undo/redo.
     set_icon (&ks.iter, icon_path, TRUE, FALSE);
 
+    // The icon was not chosen during the creation of a new element, so this must be recorded internally as a change that has been applied.
     // The icon hasn't been chosen during the addition of a new (pipe) menu or item, so changes have been applied.
     if (!gtk_widget_get_visible (ks.enter_values_box)) {
         push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
@@ -426,7 +427,7 @@ void icon_choosing_by_button_or_context_menu (void)
 
 /* 
 
-    Adds an icon, if possible, at a position passed to this function.
+    Sets an icon at the specified position if possible.
 
 */
 
@@ -484,7 +485,7 @@ gboolean set_icon (      GtkTreeIter *icon_iter,
         return FALSE;
     }
 
-    // The icon has been chosen during the addition of a new (pipe) menu or item; it is stored later.
+    // The icon was chosen during creation of a new element; store it later.
     if (gtk_widget_get_visible (ks.enter_values_box)) {
         gtk_entry_set_text (GTK_ENTRY (ks.entry_fields[ICON_PATH_ENTRY]), icon_path);
 
@@ -504,7 +505,7 @@ gboolean set_icon (      GtkTreeIter *icon_iter,
                         TS_ICON_MODIFICATION_TIME, icon_modification_time, 
                         -1);
 
-    // This function might have been called from the timeout function, with currently no selection done at that time.
+    // This may be called by the timeout function when no row is selected.
     if (!during_undo_redo && gtk_tree_selection_count_selected_rows (selection)) {
         repopulate_txt_fields_array ();
         set_entry_fields ();
@@ -515,7 +516,7 @@ gboolean set_icon (      GtkTreeIter *icon_iter,
 
 /* 
 
-    Removes icons from menus or items.
+    Removes icons from the selected menus or items.
 
 */
 
@@ -544,7 +545,7 @@ void remove_icons_from_menus_or_items (gpointer push_on_undo_stack)
     }
 
     if (gtk_tree_selection_count_selected_rows (selection) == 1) {
-        repopulate_txt_fields_array (); // There is no need to change the status of any application menu item or toolbar button.
+        repopulate_txt_fields_array (); // No need to adjust menu item or toolbar button status here.
         set_entry_fields ();
     }
 
@@ -563,7 +564,7 @@ void remove_icons_from_menus_or_items (gpointer push_on_undo_stack)
 
 /* 
 
-    Changes one or more values of a row after at least one of the entry fields has been altered.
+    Changes one or more values of a row after an entry field is modified.
 
 */
 
@@ -627,11 +628,11 @@ void change_row (gpointer changed_entry_field_ptr)
                 }
             }
             if (ks.txt_fields[ICON_PATH_TXT] && !(*entry_txt[ICON_PATH_ENTRY])) {
-                // FALSE = don't push a new item on the undo stack, as it is done anyway at the end of this function.
+                // FALSE = do not push to undo stack here; will be done later in this function.
                 remove_icons_from_menus_or_items (GUINT_TO_POINTER (FALSE));
             }
             else if (*entry_txt[ICON_PATH_ENTRY] && !STREQ (entry_txt[ICON_PATH_ENTRY], ks.txt_fields[ICON_PATH_TXT])) {
-                // TRUE = display error message when error occurs, FALSE = not during undo/redo.
+                // TRUE = show error message on failure, FALSE = not during undo/redo.
                 if (set_icon (&ks.iter, entry_txt[ICON_PATH_ENTRY], TRUE, FALSE)) {
                     gtk_style_context_remove_class (gtk_widget_get_style_context (ks.entry_fields[ICON_PATH_ENTRY]), 
                                                     "user_intervention_requested");
@@ -646,7 +647,7 @@ void change_row (gpointer changed_entry_field_ptr)
         gtk_tree_store_set (ks.treestore, &ks.iter, TS_MENU_ELEMENT, 
                             (*entry_txt[MENU_ELEMENT_OR_VALUE_ENTRY]) ? entry_txt[MENU_ELEMENT_OR_VALUE_ENTRY] : NULL, -1);
     }
-    // Option. Enabled is never shown, since it is edited directly inside the treeview.
+    // Option: "Enabled" is never shown here because it is edited directly in the tree view.
     else {
         gtk_tree_store_set (ks.treestore, &ks.iter, TS_VALUE, entry_txt[MENU_ELEMENT_OR_VALUE_ENTRY], -1);
     }
@@ -659,7 +660,7 @@ void change_row (gpointer changed_entry_field_ptr)
 
 /* 
 
-    Adopts changes from editable cells, in case it's a menu ID prevents a duplicate.
+     Applies changes from editable cells; prevents duplicate menu IDs.
 
 */
 
@@ -676,18 +677,19 @@ void cell_edited (G_GNUC_UNUSED       GtkCellRendererText *renderer,
           GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ks.treeview));
     const guint number_of_selected_rows = gtk_tree_selection_count_selected_rows (selection);
 
-    gboolean erased_separator_label = FALSE; // Default
+    gboolean erased_separator_label = FALSE; // Default value.
 
     const guint8 treestore_pos = column_number + 4; // Columns start with TS_MENU_ELEMENT, which has index 4 inside the treestore.
     const guint8 txt_fields_pos = column_number + 1; // ICON_PATH_TXT is ommitted.
 
     if (G_UNLIKELY (number_of_selected_rows > 1)) { // This means that ks.txt_fields are currently not set.
-        /*
-            It is simpler to call repopulate_txt_fields_array () than to free the current txt_field and read it (again) 
-            with gtk_tree_model_get (). There always has to be a freeing, since if two rows are currently being selected 
-            and a cell of these is changed more than once without unselecting these cells, cell_edited () is called without 
-            calling row_selected () in between, which would without freeing cause gtk_tree_model_get () to get called twice 
-            in a row, thus causing a memory leak.
+	    /*
+            It is simpler to call repopulate_txt_fields_array() than to manually free and reload 
+            the current value. There always needs to be a free operation, because if two rows are 
+            selected and a cell in them is edited more than once without deselecting, 
+            cell_edited() may be called without row_selected() being invoked in between. 
+            Without freeing first, this would cause gtk_tree_model_get() to be called twice in 
+            succession, leading to a memory leak.
         */
         repopulate_txt_fields_array ();
     }
@@ -729,7 +731,7 @@ void cell_edited (G_GNUC_UNUSED       GtkCellRendererText *renderer,
                                                                         
 /*
 
-    Builds the entry liststore for one tree store column, allowing only unique entries.
+    Builds the entry list store for a given tree store column, ensuring unique entries only.
 
 */
 
@@ -748,20 +750,15 @@ static gboolean add_all_strs_of_tree_column_to_liststore (              GtkTreeM
     }
 
     GtkTreeIter iter_loop;
-    gboolean key_does_not_exist_yet_in_liststore = TRUE; // Default
+    gboolean key_does_not_exist_yet_in_liststore = TRUE; // Default value.
 
     if (treestore_pos == TS_MENU_ELEMENT) {
         g_autofree gchar *type_txt;
 
         gtk_tree_model_get (foreach_model, foreach_iter, TS_TYPE, &type_txt, -1);
 
-        /* If the currently activated entry field refers to a label, do not add the names of actions, 
-           options, and option blocks to the entry completion list, as an addition of these names to the 
-           menu is done by the program and not a user. Actions, options, and option blocks are not labels,  
-           so they remain invisible and are thus different from (pipe) menus, items, and separators.
-           Handled like this, the texts "Execute", "Exit", "Reconfigure", "Restart", and "SessionLogout"
-           will be added if they do not appear in the context of an action. The same goes for the options 
-           "command", "prompt", "startupnotify", "enabled", "name", icon", and "wmclass". */
+        /* Skip adding names of actions, options, and option blocks, 
+           as they are inserted by the program, not the user. */
         if (streq_any (type_txt, "action", "option", "option block", NULL)) {
             return FALSE;
         }
@@ -771,14 +768,14 @@ static gboolean add_all_strs_of_tree_column_to_liststore (              GtkTreeM
 
         gtk_tree_model_get (foreach_model, foreach_iter, TS_MENU_ELEMENT, &menu_element_txt, -1);
 
-        // Show only matches from the same option type, e.g. only matches for command, for wmclass, etc.
+        // Show only matches for the same option type (e.g., only for "command" or only for "wmclass").
         if (!STREQ (menu_element_txt, ks.txt_fields[MENU_ELEMENT_TXT])) {
             return FALSE;
         }
     }
 
     if (gtk_tree_model_get_iter_first (ks.ls_model, &iter_loop)) {
-        // Ensure that each text in the list store is unique.
+        // Ensure each list store entry is unique.
         do {
             g_autofree gchar *str_loop;
 
@@ -834,7 +831,7 @@ static gboolean add_all_strs_of_tree_column_to_liststore (              GtkTreeM
 
             gtk_list_store_set (ks.liststore, &new_iter, 0, str, -1);
         }
-        else { // No element in list store yet
+        else { // No element in list store yet.
             gtk_list_store_insert_with_values (ks.liststore, &new_iter, -1, 0, str, -1);
         }
     }
@@ -844,7 +841,7 @@ static gboolean add_all_strs_of_tree_column_to_liststore (              GtkTreeM
 
 /*
 
-    Initializes the building of the entry list store, if the focus is on an entry field and the list store does not already exist.
+    Initializes building of the entry list store if the focus is on an entry field and the list store is currently empty.
 
 */
 
@@ -882,7 +879,7 @@ void build_entry_liststore (gpointer treestore_pos_ptr)
 
 /*
 
-    Checks the current text in an entry field for a possible match inside the tree store.
+    Checks the current text in an entry field for a possible match in the tree store.
 
 */
 
@@ -906,7 +903,7 @@ gboolean entry_completion_func (                    GtkEntryCompletion *entry_co
 
 /*
 
-    Checks if the focus is no longer on an entry field, so that the entry list store can be cleared since it is no longer needed.
+    Clears the entry list store if focus leaves the entry field.
 
 */
 
@@ -918,13 +915,13 @@ gboolean focus_no_longer_on_entry_field (G_GNUC_UNUSED gpointer user_data)
         gtk_list_store_clear (ks.liststore);
     }
 
-    // Propagate also default handler
+    // Also propagate to the default handler.
     return FALSE;
 }
 
 /* 
 
-    Empty labels for menus, pipe menus or items are blocked, because they would make these elements invisible.
+    Empty labels for menus, pipe menus, or items are blocked because they make the element invisible.
 
 */
 
@@ -950,13 +947,13 @@ static void empty_label_msg (void)
     show_message_dialog (_("Entry of Empty Label Blocked"),
                          "dialog-error",
                          label_txt,
-                         // Translation note: the verb "Close"
+                         // Translation note: the verb "Close".
                          _("_Close"));
 }
 
 /* 
 
-    Toggles value of toggle buttons in the treeview.
+    Toggles the value of boolean cells in the tree view.
 
 */
 
