@@ -19,7 +19,7 @@
 
 #include <gtk/gtk.h>
 
-#include <string.h> // Sometimes this might have to be included explicitly.
+#include <string.h> // May need to be included explicitly in some environments.
 
 #include "declarations_definitions_and_enumerations.h"
 #include "find_and_replace.h"
@@ -50,7 +50,7 @@ static gboolean validity_check (              GtkTreeModel *model,
 
 /* 
 
-    Simply calls find_in_columns_management () with the necessary arguments.
+    Calls find_in_columns_management() with the required arguments.
 
 */
 
@@ -62,8 +62,8 @@ static void fr_buttons_management (const gchar *column_check_button_clicked)
 
 /*
 
-    Activates the "Replace" button if something is entered in one of the entry fields and 
-    deactivates it if both entry fields no longer contain any text.
+    Activates the "Replace" button when text is entered in either entry field, 
+    and deactivates it when both fields are empty.
 
 */
 
@@ -76,7 +76,7 @@ static void fr_entry_field_content_changed (G_GNUC_UNUSED gpointer user_data)
 
 /*
 
-    If a find and replace is possible for a certain value, the new value is returned. If it is not possible NULL is returned. 
+    Returns the new value if a find-and-replace is possible for the given value; otherwise returns NULL.
 
 */
 
@@ -93,7 +93,7 @@ static gchar *compute_hypothetical_replacement (const gchar *value)
                                                        (replace_entry_str_escaped) ? replace_entry_str_escaped : replace_entry_str, 
                                                        (whole_word) ? ")\\b" : "", 
                                                        NULL);
-    gchar *new_value = NULL; // Default, no match found.
+    gchar *new_value = NULL; // Default value, no match found.
 
     if (g_regex_match_simple (final_replace_str, value, 
                               (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[MATCH_CASE]))) ? 
@@ -111,11 +111,10 @@ static gchar *compute_hypothetical_replacement (const gchar *value)
 
 /* 
 
-    Makes sure that there will be no...
-    1. ...values for the "enabled" option other than "yes" and "no"...
-    2. ...duplicate menu IDs...
-    3. ...empty (pipe) menu labels...
-    ...after a find and replace.
+    Ensures that after a find-and-replace there will be no:
+    1. Values for the "enabled" option other than "yes" or "no".
+    2. Duplicate menu IDs.
+    3. Empty labels for (pipe) menus.
 
 */
 
@@ -139,7 +138,7 @@ static gboolean validity_check (              GtkTreeModel *model,
                         TS_TYPE, &type_txt,
                         -1);
 
-    // Make sure that there will be no values for the "enabled" option other than "yes" and "no" after a find and replace.
+    // Ensure the "enabled" option has only "yes" or "no" as values after a find-and-replace.
 
     if (STREQ (type_txt, "option") && STREQ (menu_element_txt, "enabled") &&
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_VALUE]))) {
@@ -148,7 +147,7 @@ static gboolean validity_check (              GtkTreeModel *model,
         gtk_tree_model_get (model, iter, TS_VALUE, &value, -1);
         if (G_UNLIKELY ((new_value = compute_hypothetical_replacement (value)) && 
                         !streq_any (new_value, "yes", "no", NULL))) {
-            // Translation note: Do not translate "enabled", "yes", "no"
+            // Translation note: Do not translate the words "enabled", "yes", or "no".
             g_autofree gchar *err_msg = g_strdup_printf (_("An <b>\"enabled\"</b> option can't have a value other than "
                                                            "<b>\"yes\"</b> or <b>\"no\"</b> and thus a replacement of "
                                                            "\"%s\" with \"%s\" won't be done.\n\n"
@@ -164,7 +163,7 @@ static gboolean validity_check (              GtkTreeModel *model,
         }
     }
 
-    // Make sure that there will be no duplicate menu IDs after a find and replace.
+    // Ensure there are no duplicate menu IDs after a find-and-replace.
 
     if (streq_any (type_txt, "menu", "pipe menu", NULL) && 
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_MENU_ID]))) {
@@ -189,10 +188,13 @@ static gboolean validity_check (              GtkTreeModel *model,
             }
 
             /* 
-               Duplicate menu IDs can also occur if for example for both menu IDs "menu1" and "menu2" the trailing numbers are removed.
-               All hypothetical new menu IDs are stored inside a list, and then sorted, because with that it is enough to compare a 
-               menu ID with the following one inside the list. If they are identical, there would be a duplicate menu ID after the 
-               execution of the "find and replace" action.
+			
+			   Duplicate menu IDs can also occur if, for example, both "menu1" and "menu2" 
+               have their trailing numbers removed.
+               All hypothetical new menu IDs are stored in a list and then sorted, so it is 
+               sufficient to compare each menu ID with the next in the list. 
+               If they match, a duplicate would result after executing the find-and-replace.
+
             */
             if (*no_invalid_replacements) {
                 gchar *menu_IDs_before_and_after_txt = g_strdup_printf ("%s%c%s", new_menu_id_txt, 
@@ -204,9 +206,9 @@ static gboolean validity_check (              GtkTreeModel *model,
                 if (g_slist_length (fr_data->menu_IDs_before_and_after) > 1) {
                     FOREACH_IN_LIST (fr_data->menu_IDs_before_and_after, menu_ids_loop) {
                         if (menu_ids_loop->next) {
-                            // x1F (dec. 31) = unit separator
+                            // 0x1F (decimal 31) = unit separator
                             g_auto(GStrv) menu_IDs_before_and_after_pair1 = g_strsplit (menu_ids_loop->data, "\x1F", -1);
-                            // x1F (dec. 31) = unit separator
+                            // 0x1F (decimal 31) = unit separator
                             g_auto(GStrv) menu_IDs_before_and_after_pair2 = g_strsplit (menu_ids_loop->next->data, "\x1F", -1);
 
                             if (G_UNLIKELY (STREQ (menu_IDs_before_and_after_pair1[0], menu_IDs_before_and_after_pair2[0]))) {
@@ -237,7 +239,7 @@ static gboolean validity_check (              GtkTreeModel *model,
 
     if (!(*with_entry_str)) {
 
-        // Make sure that there will be no empty (pipe) menu and item labels after a find and replace.
+        // Ensure there are no empty (pipe) menu or item labels after a find-and-replace.
 
         if (streq_any (type_txt, "menu", "pipe menu", "item", NULL) && 
             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_MENU_ELEMENT]))) {
@@ -277,7 +279,7 @@ static gboolean validity_check (              GtkTreeModel *model,
             }
         }
 
-        // Make sure that executes of pipe menus are not emptied.
+        // Ensure that the "execute" field of pipe menus is not emptied.
 
         if (STREQ (type_txt, "pipe menu") && 
             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_EXECUTE]))) {
@@ -292,7 +294,7 @@ static gboolean validity_check (              GtkTreeModel *model,
 
                 gtk_tree_model_get (model, iter, TS_MENU_ID, &menu_id_txt, -1);
 
-                // Translation note: Do not translate "execute"
+                // Translation note: Do not translate the word "execute".
                 g_autofree gchar *err_msg = g_strdup_printf (_("The execute instruction of the pipe menu <b>\"%1$s\"</b> "
                                                                "with the menu ID <b>\"%2$s\"</b> won't be deleted, "
                                                                "because this would render this pipe menu useless.\n\n"
@@ -306,14 +308,15 @@ static gboolean validity_check (              GtkTreeModel *model,
         }
     }
 
-    return (!(*no_invalid_replacements)); // return value == TRUE -> Stop iterating through the tree store.
+    return (!(*no_invalid_replacements)); // If TRUE is returned, stop iterating through the tree store.
 }
 
 /*
 
-    Execute a find and replace. "Type" and "Element visibilty" are excluded, since their values have to be unmodifiable.
-    This, the uniqueness of each menu ID and the only two possible values for the "enabled" option ("yes" and "no") have already 
-    been taken care of.
+    Executes a find-and-replace. "Type" and "Element visibility" are excluded, 
+    since their values must remain unmodifiable.
+    Uniqueness of each menu ID and the two valid values for the "enabled" option 
+    ("yes" and "no") are already enforced elsewhere.
 
 */
 
@@ -345,7 +348,7 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
         gtk_tree_model_get (model, iter, columns_cnt + TREEVIEW_COLUMN_OFFSET, &current_column_txt, -1);
 
         if (!(*replace_entry_str)) {
-            // The program allows to find empty fields and fill them with a value, provided they can also be entered manually.
+			// Allows finding empty fields and filling them with a value, provided they can also be entered manually.
             if (!NOT_NULL_AND_NOT_EMPTY (current_column_txt) && 
                 // The invalid types "action", "option block", and "option" have already been taken care of above.
                 (columns_cnt == COL_MENU_ELEMENT || 
@@ -354,9 +357,9 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
                  (columns_cnt == COL_EXECUTE && STREQ (type_txt, "menu") && !gtk_tree_model_iter_has_child (model, iter)))) {
                 gtk_tree_store_set (ks.treestore, iter, columns_cnt + TREEVIEW_COLUMN_OFFSET, with_entry_str, -1);
 
-                /* It's simpler to overwrite the visibility status regardless of the previous status than to query the status first.
-                   Only the status of the types "menu", "pipe menu", "item", and "separator" is overwritten, since the other types 
-                   were already skipped above. */
+                /* It is simpler to overwrite the visibility status without checking it first.
+                   Only the status for "menu", "pipe menu", "item", and "separator" is overwritten, 
+                   since other types were already skipped above. */
                 if (columns_cnt == COL_MENU_ELEMENT) {
                     gtk_tree_store_set (ks.treestore, iter, TS_ELEMENT_VISIBILITY, "visible", -1);
                     *menu_item_or_sep_has_been_visualized = TRUE;
@@ -367,7 +370,7 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
                     ks.menu_ids = g_slist_prepend (ks.menu_ids, g_strdup (with_entry_str));
                 }
 
-                // By adding a text to the "Execute" field, a menu without children has been turned into a pipe menu.
+                // Adding text to the "Execute" field converts a menu without children into a pipe menu.
                 if (columns_cnt == COL_EXECUTE && STREQ (type_txt, "menu") && !gtk_tree_model_iter_has_child (model, iter)) {
                     gtk_tree_store_set (ks.treestore, iter, TS_TYPE, "pipe menu", -1);
                 }
@@ -421,10 +424,10 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
 
 /*
 
-    If by find and replace one or several labelless menus, items, and/or separators have received a label, 
-    this means all menus, items, and separators will have a label now.
-    Instead of checking if there are any menus/items/separators left for which the visibility would have 
-    to be set to "visible", for simplicity visibility is set to "visible" for all menus, items, and separators.
+    If one or more menus, items, or separators without labels receive a label through 
+    find-and-replace, it means all such elements now have labels.
+    For simplicity, instead of checking which elements still need visibility set to "visible", 
+    the visibility of all menus, items, and separators is set to "visible".
 
 */
 
@@ -446,7 +449,7 @@ static gboolean set_all_menus_items_and_seps_to_visible (              GtkTreeMo
 
 /*
 
-    Does a number of checks, then starts the actual find and replace action.
+    Performs several checks, then starts the actual find-and-replace action.
 
 */
 
@@ -454,9 +457,9 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 {
     FRData fr_data = {
         .menu_IDs_before_and_after = NULL,
-        .replacements_done_cnt = 0, // Default
-        .no_invalid_replacements = TRUE, // Default
-        .menu_item_or_sep_has_been_visualized = FALSE // Default
+        .replacements_done_cnt = 0, // Default value.
+        .no_invalid_replacements = TRUE, // Default value.
+        .menu_item_or_sep_has_been_visualized = FALSE // Default value.
     };
 
     guint8 columns_cnt;
@@ -465,7 +468,7 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
         return;
     }
 
-    gboolean no_find_in_columns_buttons_clicked = TRUE; // Default
+    gboolean no_find_in_columns_buttons_clicked = TRUE; // Default value.
 
     for (columns_cnt = 0; columns_cnt < COL_ELEMENT_VISIBILITY; ++columns_cnt) {
         if (columns_cnt == COL_TYPE) {
@@ -477,7 +480,7 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
         }
     }
 
-    if (no_find_in_columns_buttons_clicked) { // No column chosen = not a valid find & replace
+    if (no_find_in_columns_buttons_clicked) { // No column chosen → invalid find-and-replace.
         for (columns_cnt = 0; columns_cnt < COL_ELEMENT_VISIBILITY; ++columns_cnt) {
             if (columns_cnt == COL_TYPE) {
                 continue;
@@ -493,20 +496,20 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
     if (fr_data.no_invalid_replacements) {
         g_autofree gchar *replacements_done_label_txt;
-        const gchar *small_numbers_spelled_out[] = { // Translation note: "once" in the sense of "one time".
+        const gchar *small_numbers_spelled_out[] = { // Translation note: "once" means "one time" here.
                                                      N_("once"), 
                                                      N_("twice"), N_("three times"), N_("four times"), N_("five times"), 
                                                      N_("six times"), N_("seven times"), N_("eight times"), N_("nine times") };
 
-        fr_data.replacements_done_cnt = 0; // Default
+        fr_data.replacements_done_cnt = 0; // Default value.
 
         gtk_tree_model_foreach (ks.ts_model, (GtkTreeModelForeachFunc) find_and_replace_iteration, &fr_data);
 
         replacements_done_label_txt = (fr_data.replacements_done_cnt) ? 
                                       ((fr_data.replacements_done_cnt < 10) ? 
-                                       // Translation note: The translation should work for %s getting replaced with phrases ranging from "once" to "nine times"
+                                       // Translation note: Must work when %s is replaced with phrases from "once" to "nine times".
                                        g_strdup_printf (_("Search key replaced %s."), _(small_numbers_spelled_out[(fr_data.replacements_done_cnt) - 1])) : 
-                                       // Translation note: The translation should work for %i getting replaced with positive numbers
+                                       // Translation note: Must work when %i is replaced with a positive number.
                                        g_strdup_printf (ngettext ("Search key replaced %i times.", "Search key replaced %i times.", fr_data.replacements_done_cnt), fr_data.replacements_done_cnt)) : 
                                        g_strdup (_("Search key not found."));
         gtk_label_set_text (GTK_LABEL (ks.fr_replacements_done_label), replacements_done_label_txt);
@@ -523,13 +526,13 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
         }
     }
 
-    // Cleanup. Setting to NULL is unnecessary, since this is part of a local struct and always initialized to NULL in the beginning.
+    // Cleanup. Setting to NULL is unnecessary because this is a local struct, which is always initialized to NULL at the start.
     g_slist_free_full (fr_data.menu_IDs_before_and_after, (GDestroyNotify) g_free);
 }
 
 /*
 
-    Shows the find and replace dialog window.
+    Displays the Find and Replace dialog window.
 
 */
 
@@ -558,13 +561,13 @@ void show_find_and_replace_dialog (void)
     GtkWidget *columns_grid = gtk_grid_new ();
     GtkWidget *special_options_grid = gtk_grid_new ();
     enum { FR_REPLACE_LABEL, FR_IN_LABEL, FR_WITH_LABEL, NUMBER_OF_FR_LABEL_FIELDS };
-    const gchar *fr_label_txts[] = { // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+    const gchar *fr_label_txts[] = { // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y".
                                      _("<b>Replace: </b>"), 
-                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
-                                     // A translation of "In" as "Where" would also work
+                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y".
+                                     // A translation of "In" as "Where" would also work.
                                      _("<b>In: </b>"), 
-                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
-                                     // A translation of "With" as "With what" would also work
+                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y".
+                                     // A translation of "With" as "With what" would also work.
                                      _("<b>With: </b>") };
     GtkWidget *fr_labels[NUMBER_OF_FR_LABEL_FIELDS] = { gtk_label_new (NULL), gtk_label_new (NULL), gtk_label_new (NULL) };
     const gchar *special_options_txts[] = { // This is for a search functionality. A translation of "case sensitive" or "distinguish between uppercase and lowercase letters" would also work.
@@ -587,7 +590,7 @@ void show_find_and_replace_dialog (void)
     gtk_grid_attach (GTK_GRID (grid), columns_grid, 1, 1, 1, 1);
 
     for (columns_cnt = 0; columns_cnt < COL_ELEMENT_VISIBILITY; ++columns_cnt) {
-        if (columns_cnt == COL_TYPE) { // The text for the type of a menu element has to be unmodifiable.
+        if (columns_cnt == COL_TYPE) { // The text for the menu element's type must be unmodifiable.
             continue;
         }
 
@@ -638,7 +641,7 @@ void show_find_and_replace_dialog (void)
     g_signal_connect_swapped (gtk_dialog_get_widget_for_response (GTK_DIALOG (ks.fr_dialog), 2), "clicked", 
                               G_CALLBACK (gtk_widget_destroy), ks.fr_dialog);
 
-    // Default settings
+    // Default settings.
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ks.fr_in_all_columns), TRUE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[REGULAR_EXPRESSION]), TRUE);
     gtk_dialog_set_response_sensitive (GTK_DIALOG (ks.fr_dialog), 1, FALSE);
