@@ -851,8 +851,8 @@ void save_menu (gchar *save_as_filename)
         g_autofree gchar *standard_output = NULL;
 
         if (G_UNLIKELY (!g_spawn_command_line_sync ("ps cax", &standard_output, NULL, NULL, &error))) {
-            g_autofree gchar *err_msg = g_strdup_printf (_("<b>The menu has been saved, but it wasn't possible to obtain a list "
-                                                           "of the running processes to determine if Openbox is currently running.\n\n"
+            g_autofree gchar *err_msg = g_strdup_printf (_("<b>The menu has been saved, but it was not possible to obtain a list of "
+                                                           "running processes to determine if Openbox is currently running.\n\n"
                                                            "Error:</b> %s"), 
                                                          error->message);
 
@@ -912,10 +912,10 @@ void save_menu (gchar *save_as_filename)
 
         if (invisible_orphaned_menu_has_been_converted_to_visible) {
             show_message_dialog (_("Previously Invisible Orphaned Menus Are Now Visible"), "gtk-info", 
-                                 _("This menu contained invisible orphaned menus. Since this menu has been saved "
-                                   "right now with the \"Keep Root Menu Separate in Saved Menu File\" option "
-                                   "being <b>disabled</b>, these menus have become part of the root menu now and, "
-                                   "<b>provided that they have a label</b>, are therefore no longer invisible."), 
+                                 _("This menu contained invisible orphaned menus. Since it has just been saved "
+                                   "with the \"Keep Root Menu Separate in Saved Menu File\" option <b>disabled</b>, "
+                                   "these menus have now become part of the root menu and, <b>if they have a label</b>, "
+                                   "are no longer invisible."), 
 								 // Translation note: the verb "Close"
                                  _("_Close"));
         }
